@@ -1,7 +1,7 @@
 #!/bin/sh
 
 JAVA=`which java`
-WEB_SPA="webspa-08.jar"
+WEB_SPA="webspa-0.8.jar"
 JAVA_PARAMS="-Xms64m -Xmx256m"
 
 umask 077
